﻿/*
    『概要』
    EKLを利用して、カメラ画像を表示する最小限のサンプルです。

    EKLの内、主に次の機能が利用されています。
        - FrameExtensions
        - KinectSensorExtensions
*/

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

//追加
using Microsoft.Kinect;
using ExtendKinectLibrary;

namespace SimpleCameraWPF
{
    /// <summary>
    /// MainWindow.xaml の相互作用ロジック
    /// </summary>
    public partial class MainWindow : Window
    {

        KinectSensor kinect;

        public MainWindow()
        {
            InitializeComponent();

            //Kinectが一台も繋がっていなかったら終了する。
            if (KinectSensor.KinectSensors.Count == 0)
            {
                MessageBox.Show("Failed to find some Kinect sensor.");
                this.Close();
            }
            else
            {
                //Kinectの初期化と設定
                kinect = KinectSensor.KinectSensors[0];
                kinect.ColorFrameReady += new EventHandler<ColorImageFrameReadyEventArgs>(kinect_ColorFrameReady);
                kinect.ColorStream.Enable(ColorImageFormat.RgbResolution640x480Fps30);
                kinect.Start();

                //Windowの設定
                this.Closed += new EventHandler(MainWindow_Closed);
            }
        }

        /// <summary>
        /// Windowが閉じられるときの処理。
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        void MainWindow_Closed(object sender, EventArgs e)
        {
            if (kinect != null)
                kinect.Close();//Kinectを停止してインスタンスを破棄する。
        }

        /// <summary>
        /// カメラのデータがKinectから流れて来た時の処理。
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        void kinect_ColorFrameReady(object sender, ColorImageFrameReadyEventArgs e)
        {
            ColorImageFrame temp = e.OpenColorImageFrame();

            if (temp != null)
            {
                //カメラ画像を表示する
                image1.Source = temp.GetBitmapSource();

                //ImageFrameを破棄する
                temp.Dispose();
            }
        }

    }
}
